camelot.camelot.view.validator

Package camelot :: Package camelot :: Package view :: Module validator |
[hide private]
[frames] | no frames]

# Module validator

source code

Classes | [hide private]
| Validator A validator class validates an entity before flushing it to the database and provides the user with feedback if the entity is not ready to flush

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.validator')`